@@ -103,3 +103,6 @@ __version__ = getVersion()
 DEBUG = False
 # this flag is set by gavo serve if this is a long-running server process
 IS_DACHS_SERVER = False
+# this flag is set by gavo serve if it successfully set up an https
+# connection
+LISTENING_TO_HTTPS = False
