@@ -196,6 +196,14 @@ for numpyType, adapter in [
 		# what's not there we don't need to adapt
 		pass
 
+# Override psycopg2's mapping of numeric to decimal, because our
+# serialisers (votable, fits, json) don't really work with decimal.
+psycopg2.extensions.register_type(
+	psycopg2.extensions.new_type(
+		psycopg2.extensions.DECIMAL.values,
+		"numeric_float",
+		lambda value, cursor: float(value) if value is not None else None))
+
 
 from gavo.utils import pyfits
 psycopg2.extensions.register_adapter(pyfits.Undefined, NULLAdapter)
@@ -502,7 +510,7 @@ class PostgresQueryMixin(object):
 	def getServerVersion(self, digits=2):
 		"""returns the version of the connection's server to digits numbers.
 		"""
-		bannerString = list(self.query("SELECT version()"))[0][0]
+		bannerString = list(self.connection.query("SELECT version()"))[0][0]
 		return parseBannerString(bannerString, digits)
 
 	def getPrimaryIndexName(self, tableName):
@@ -514,7 +522,7 @@ class PostgresQueryMixin(object):
 	def schemaExists(self, schema):
 		"""returns True if the named schema exists in the database.
 		"""
-		matches = list(self.query("SELECT nspname FROM"
+		matches = list(self.connection.query("SELECT nspname FROM"
 			" pg_namespace WHERE LOWER(nspname)=%(schemaName)s", {
 					'schemaName': schema.lower(),
 			}))
@@ -526,7 +534,7 @@ class PostgresQueryMixin(object):
 		See _parseTableName on the meaning of the arguments.
 		"""
 		schema, tableName = _parseTableName(tableName, schema)
-		res = list(self.query("SELECT indexname FROM"
+		res = list(self.connection.query("SELECT indexname FROM"
 			" pg_indexes WHERE schemaname=lower(%(schema)s) AND"
 			" tablename=lower(%(tableName)s) AND"
 			" indexname=lower(%(indexName)s)", locals()))
@@ -540,7 +548,7 @@ class PostgresQueryMixin(object):
 		"""
 		colNames = set(n.lower() for n in colNames)
 		res = [r[0] for r in 
-			self.query("SELECT attnum FROM pg_attribute WHERE"
+			self.connection.query("SELECT attnum FROM pg_attribute WHERE"
 				" attrelid=%(relOID)s and attname IN %(colNames)s",
 				locals())]
 		res.sort()
@@ -566,7 +574,7 @@ class PostgresQueryMixin(object):
 		except Error: # Some of the items related probably don't exist
 			return False
 
-		res = list(self.query("""SELECT conname FROM pg_constraint WHERE
+		res = list(self.connection.query("""SELECT conname FROM pg_constraint WHERE
 			contype='f'
 			AND conrelid=%(srcOID)s
 			AND confrelid=%(destOID)s
@@ -598,7 +606,7 @@ class PostgresQueryMixin(object):
 		
 		*** postgres specific ***
 		"""
-		res = list(self.query(
+		res = list(self.connection.query(
 			"select typname from pg_type where oid=%(oid)s", {"oid": oid}))
 		return res[0][0]
 
@@ -628,7 +636,7 @@ class PostgresQueryMixin(object):
 		This will raise a KeyError with tableName if the table isn't known
 		to postgres.
 		"""
-		res = list(self.query(
+		res = list(self.connection.query(
 			"SELECT reltuples FROM pg_class WHERE oid = %(tableName)s::regclass",
 			locals()))
 		if not res:
@@ -638,7 +646,7 @@ class PostgresQueryMixin(object):
 	def roleExists(self, role):
 		"""returns True if there role is known to the database.
 		"""
-		matches = list(self.query(
+		matches = list(self.connection.query(
 			"SELECT usesysid FROM pg_user WHERE usename=%(role)s", 
 			locals()))
 		return len(matches)!=0
@@ -649,7 +657,7 @@ class PostgresQueryMixin(object):
 		tableName may be schema qualified.  If it is not, public is assumed.
 		"""
 		schema, tableName = _parseTableName(tableName, schema)
-		res = list(self.query("SELECT oid FROM pg_class WHERE"
+		res = list(self.connection.query("SELECT oid FROM pg_class WHERE"
 			" relname=%(tableName)s AND"
 			" relnamespace=(SELECT oid FROM pg_namespace WHERE nspname=%(schema)s)",
 			locals()))
@@ -675,7 +683,7 @@ class PostgresQueryMixin(object):
 		"""
 		schema, tableName = _parseTableName(tableName, schema)
 		res = list(
-			self.query("""SELECT table_name, table_type FROM
+			self.connection.query("""SELECT table_name, table_type FROM
 				information_schema.tables WHERE (
 						table_schema=%(schemaName)s 
 						OR table_type='LOCAL TEMPORARY')
@@ -690,7 +698,8 @@ class PostgresQueryMixin(object):
 					"select table_name from information_schema.tables"
 					"  where table_name='pg_matviews'")):
 				res = list(
-					self.query("""SELECT matviewname, 'MATERIALIZED VIEW' AS table_type
+					self.connection.query(
+						"""SELECT matviewname, 'MATERIALIZED VIEW' AS table_type
 						FROM pg_matviews
 						WHERE 
 							schemaname=%(schemaName)s 
@@ -721,7 +730,7 @@ class PostgresQueryMixin(object):
 			"FOREIGN TABLE": "FOREIGN TABLE",
 			"BASE TABLE": "TABLE",
 			"LOCAL TEMPORARY": "TABLE"}[tableType]
-		self.query("DROP %s %s %s"%(
+		self.connection.execute("DROP %s %s %s"%(
 			dropQualification, 
 			tableName,
 			"CASCADE" if cascade else ""))
@@ -729,7 +738,7 @@ class PostgresQueryMixin(object):
 	def getSchemaPrivileges(self, schema):
 		"""returns (owner, readRoles, allRoles) for schema's ACL.
 		"""
-		res = list(self.query("SELECT nspacl FROM pg_namespace WHERE"
+		res = list(self.connection.query("SELECT nspacl FROM pg_namespace WHERE"
 			" nspname=%(schema)s", locals()))
 		return self.parsePGACL(res[0][0])
 
@@ -739,7 +748,7 @@ class PostgresQueryMixin(object):
 
 		*** postgres specific ***
 		"""
-		res = list(self.query("SELECT relacl FROM pg_class WHERE"
+		res = list(self.connection.query("SELECT relacl FROM pg_class WHERE"
 			" lower(relname)=lower(%(tableName)s) AND"
 			" relnamespace=(SELECT oid FROM pg_namespace WHERE nspname=%(schema)s)",
 			locals()))
@@ -869,7 +878,7 @@ class QuerierMixin(PostgresQueryMixin, StandardQueryMixin):
 		self.connection = getDBConnection(
 			**self.connection._getDBConnectionArgs)
 		self._reconnecting = True
-		res = self.query(query, data, timeout)
+		res = self.connection.query(query, data, timeout)
 		self._reconnection = False
 		return res
 
@@ -883,6 +892,11 @@ class QuerierMixin(PostgresQueryMixin, StandardQueryMixin):
 
 		Use either connection.query or connection.execute in new code.
 		"""
+		warnings.warn("You are using querier.query (or perhaps table.query)."
+			"  This has terrible semantics; use querier.connection.query"
+			" for statements returning rows and .execute for DDL statements.",
+			category=FutureWarning)
+
 		if self.connection is None:
 			raise utils.ReportableError(
 				"SimpleQuerier connection is None.",
@@ -1015,7 +1029,6 @@ SELECT (
 ' LANGUAGE SQL IMMUTABLE;
 """
 
-
 def _initPsycopg():
 	"""does any DaCHS-specific database setup necessary.
 
@@ -1033,7 +1046,7 @@ def _initPsycopg():
 			pgsphere.preparePgSphere(conn)
 		except:
 			warnings.warn("pgsphere missing -- ADQL, pg-SIAP, and SSA will not work")
-		
+	
 		# Add symmetrised q3c_joins if q3c is in use and the functions are
 		# not already defined
 		# TODO: Delete this when q3c is fixed.
