@@ -158,7 +158,8 @@ class FieldFragment(nevowc.CommonRenderers, template.Element):
             error = formErrors.getFieldError(field.key)
             # field.render wants almost unprocessed requests.args if
             # there was an error.
-            formData = dict([(k.decode("utf-8", "ignore"),v) 
+            formData = util.CaseSemisensitiveDict(
+                [(k.decode("utf-8", "ignore"),v) 
                 for k,v in list(request.args.items())])
         else:
             error = None
@@ -359,7 +360,8 @@ class Form(AddHelperMixin, object):
         charset = 'utf-8'
 
         # Get the request args and decode the arg names
-        args = dict([(k.decode(charset),v) for k,v in list(request.args.items())])
+        args = util.CaseSemisensitiveDict(
+            [(k.decode(charset),v) for k,v in list(request.args.items())])
 
         # Find the callback to use, defaulting to the form default
         callback, validate = self.callback, True
@@ -497,7 +499,7 @@ class FormsResourceBehaviour(object):
             # in validation problems for them, so errors is
             # just something with an add method.
             ignoredErrors = set()
-            args = dict((k.decode("utf-8"), v) 
+            args = util.CaseSemisensitiveDict((k.decode("utf-8"), v) 
                 for k,v in request.args.items())
 
             for key, value in args.items():
