@@ -75,7 +75,8 @@ def _makeStringArray(values, colInd, colDesc):
 def _getNullValue(colDesc):
 	"""returns a null value we consider ok for a column described by colDesc.
 
-	This is supposed to be in the column data type.
+	This is mainly intended for array serialisation.  It is also
+	used for column construction for integer types.
 	"""
 	length = votcommon.getLength(colDesc["arraysize"])
 	if length and length>1:
@@ -88,8 +89,10 @@ def _getNullValue(colDesc):
 		if (colDesc["datatype"]=="float"
 			or colDesc["datatype"]=="double"):
 			nullValue = float("NaN")
+
 		elif colDesc["datatype"]=="text":
 			nullValue = ""
+
 	else:
 		nullValue = _typeConstructors[colDesc["datatype"]](nullValue)
 	
@@ -98,10 +101,6 @@ def _getNullValue(colDesc):
 
 def _computeTypeCode(colDesc):
 	"""returns a FITS type code suitable for colDesc.
-
-	This is deficient in that we don't do variable length arrays
-	and the like for now.  This may need extension when we want
-	to get fancy with FITS tables.
 	"""
 	baseCode = _fitsCodeMap[colDesc["datatype"]]
 	length = votcommon.getLength(colDesc["arraysize"])
@@ -110,12 +109,10 @@ def _computeTypeCode(colDesc):
 		return length, baseCode
 
 	elif length is None:
-		# NOTE: Strings have special handling in _makeExtension.
-		# Here, we just bail out for now.
-		# There actually is support for variable-length arrays
-		# in FITS.  Let's see if we need it at some point
-		raise common.CannotSerializeIn("fits")
-	
+		# a variable-length array (other than a string).  We, in particular,
+		# need this for polygons.
+		return length, "P%s()"%(baseCode)
+
 	else:
 		return length, "%d%s"%(length, baseCode)
 
@@ -125,15 +122,18 @@ def _makeValueArray(values, colInd, colDesc):
 	stored in the colInd-th column of values.
 	"""
 	length, typecode = _computeTypeCode(colDesc)
-	nullValue = _getNullValue(colDesc)
 	nan = float("NaN")
 
-	if length>1:
+	if length is None:
+		# That's a variable-length array that we'll fill from a 
+		# numpy object array
+		return typecode, numpy.array([list(v[colInd]) for v in values], 
+			dtype=numpy.object)
+
+	elif length>1:
 		# numpy 1:1.12.1-3 and pyfits from astropy 1.3-8 apparently
 		# have trouble with masked arrays here, so we exploit
 		# that in the VO and for floats NaN and NULL is treated equivalently.
-		# That doesn't help for ints.  Let's hope we can go back to masked
-		# arrays here until then.
 		nullArray = numpy.array([nan]*length)
 		def mkval(v):
 			if v is None:
@@ -142,7 +142,7 @@ def _makeValueArray(values, colInd, colDesc):
 				return numpy.array(v)
 
 	else:
-		def mkval(v):
+		def mkval(v, nullValue=_getNullValue(colDesc)):
 			if v is None:
 				if nullValue is None:
 					raise ValueError("While serializing a FITS table: NULL"
@@ -174,9 +174,12 @@ def _makeExtension(serMan):
 			makeArray = _makeValueArray
 		
 		typecode, arr = makeArray(values, colInd, colDesc)
-		if typecode[-1] in 'ED':
-			nullValue = None  # (NaN implied)
-		else:
+		# only pass on null values to integral types; FITS doesn't support
+		# anything else, and I'll just leave Nones in non-integral columns
+		# to astropy.io.fits -- with all the mess involved, in particular
+		# that \0 and NULL or NaN and NULL can't be told apart in FITS.
+		nullValue = None
+		if typecode in 'BIJK':
 			nullValue = _getNullValue(colDesc)
 		
 		columns.append(pyfits.Column(name=str(colDesc["name"]), 
