@@ -67,7 +67,7 @@ class CBooster(object):
 		# XXX TODO: take this from the embedding data's make;
 		# DirectGrammars can't be outside of a data element any more anyway.
 		mat = re.search("(?m)^#define QUERY_N_PARS\s+(\d+)", 
-			open(self.srcName).read())
+			open(self.srcName, "r", encoding="utf-8").read())
 		if not mat:
 			raise base.ReportableError("Booster function doesn't define QUERY_N_PARS")
 		query_n_pars = mat.group(1)
