@@ -184,7 +184,7 @@ VO_SCHEMATA = [
 		"region-v1.20.xsd",
 		"TAPRegExt-v1.0.xsd",
 		"UWS-v1.1.xsd",
-		"VODataService-v1.1.xsd",
+		"VODataService-v1.2.xsd",
 		"VOEvent-1.0.xsd",
 		"VOEventRegExt-v2.0.xsd",
 		"VORegistry-1.1.xsd",
@@ -361,34 +361,44 @@ def getUnreferenced(items):
 		
 def debugReferenceChain(ob):
 	"""a sort-of-interactive way to investigate where ob is referenced.
+
+	* d -- enter pdb (look at ob, perhaps at nob)
+	* u -- follow 
+	* x -- continue execution
 	"""
 	import gc
 	while True:
-		print(repr(ob))
+		print("Current object: ", repr(ob))
 		refs = gc.get_referrers(ob)
+		if not refs:
+			print("Not referenced -- exiting")
+			break
+
 		while refs:
 			nob = refs.pop()
 			print(len(refs), utils.makeEllipsis(repr(nob)))
-			res = input()
+			res = input("?")
 			
-			if res=="h":
-				print("d,x,<empty>")
-
-			elif res=="d":
-				import pdb;pdb.set_trace()
+			if res=="d":
+				import pdb;pdb.Pdb(nosigint=True).set_trace()
 
 			elif res=="x":
 				return
 
-			elif res:
+			elif res=="u":
 				ob = nob
 				break
 
+			elif res=="?":
+				print("d, x, u, <empty>")
+
+			elif not refs:
+				print("Referrers exhausted, warping")
+
+
 NEWIDS = set()
 
-from twisted.web.http import HTTPChannel
-
-def memdebug():
+def memdebug(watchClass=base.Structure):
 	"""a debug method to track memory usage after some code has run.
 
 	This is typically run from ArchiveService.getChild, since request
@@ -403,18 +413,19 @@ def memdebug():
 	if hasattr(base, "getNewStructs"):
 		ns = base.getNewStructs()
 		print(">>>>>> new objects:", len(ns))
-		if len(ns)<110:
+		if len(ns)<11000:
 			ur = getUnreferenced(ns)
 			print(">>>>>> new externally referenced:", len(ur))
 			del ur
-			print(set(getattr(getattr(ob, "__class__", None), "__name__", "whatsit") for ob in ns))
-			for ob in ns:
-				if getattr(getattr(ob, "__class__", None), "__name__", "whatsit"
-						).endswith("cellxx"):
-					debugReferenceChain(ob)
-					break
+			print([ob for ob in ns if isinstance(ob, watchClass)])
+			if True:
+				try:
+					debugReferenceChain(
+						[ob for ob in ns if isinstance(ob, watchClass)][0])
+				except IndexError:
+					pass
 
-	base.getNewStructs = getMemDiffer(ofClass=HTTPChannel)
+	base.getNewStructs = getMemDiffer(ofClass=watchClass)
 
 
 @contextlib.contextmanager
