@@ -74,12 +74,17 @@ def _makeColumnFromFieldInfo(ctx, colName, fi):
 	"""
 	if len(fi.userData)==1:
 		res = svcs.OutputField.fromColumn(fi.userData[0])
-		# the following is to undo column renaming for postgres-forbidden
-		# column names
 		if hasattr(fi.userData[0], "originalName"):
+			# the following is to undo column renaming for postgres-forbidden
+			# column names
 			colName = fi.userData[0].originalName
+		elif fi.userData[0].name.lower()==colName:
+			# undo case normalisation done by the ADQL machinery
+			# if we're reasonably sure there's no intervening AS
+			colName = fi.userData[0].name
 	else: 
 		res = base.makeStruct(svcs.OutputField, name=colName)
+
 	res.name = ctx.getName(colName)
 	res.ucd = fi.ucd
 	res.unit = fi.unit
@@ -256,7 +261,7 @@ def _addTableMeta(translated, query, tree, table):
 				base.getMetaText(sourceTD.rd, "description", ""),
 				infoName="src_res", 
 				infoValue="Contains traces from resource %s"%(sourceTD.rd.sourceId))
-			for m in sourceTD.iterMeta("copyright", propagate=True):
+			for m in sourceTD.iterMeta("rights", propagate=True):
 				table.addMeta("info",
 					m.getContent("text"),
 					infoName="copyright", 
@@ -280,8 +285,8 @@ def _addTableMeta(translated, query, tree, table):
 					# and are untainted (cave: join using)
 					# for now, let's just fake it:
 					try:
+						destCol = table.tableDef.getColumnByName(idColumn.name)
 						table.addMeta("_associatedDatalinkService", None)
-						destCol = table.tableDef.getColumnByName(idColumn.name.lower())
 						table.addMeta("_associatedDatalinkService.idColumn", 
 							destCol.name)
 						serviceId = m.getMeta("serviceId").getContent()
