@@ -994,7 +994,14 @@ rscdef.addProcDefObject("quoteProductKey", quoteProductKey)
 def makeProductLink(key, withHost=True, useHost=None):
 	"""returns the URL at which a product can be retrieved.
 
-	key can be an accref string or an RAccref
+	key can be an accref string or an RAccref.
+
+	Note that this is using the preferred host as the basic URL.  If
+	you are running dual-protocol http/https and you ingest results
+	of this function into the database, it is advisable to cut off
+	the scheme part of the URI (e.g., ``split(":", 1)[-1]``).  In
+	data products served, DaCHS will then put in the scheme used
+	for the query.
 	"""
 	url = base.makeSitePath("/getproduct/%s"%RAccref.fromString(key))
 	if withHost:
