@@ -445,7 +445,7 @@ class UWS(object):
 
 
 class UWSWithQueueing(UWS):
-	"""A UWS with support for queuing.
+	"""A UWS with support for queueing.
 
 	Queuing is done on UWS level rather than at transitions.  With a plain
 	UWS, if something is put on the queue, it must be started by the 
@@ -593,7 +593,7 @@ class UWSWithQueueing(UWS):
 
 
 class ParameterRef(object):
-	"""A UWS parameter.that is (in effect) a URL.
+	"""A UWS parameter that is (in effect) a URL.
 
 	This always contains a URL.  In case of uploads, the tap renderer makes
 	sure the upload is placed into the upload directory and generates a
