@@ -489,7 +489,7 @@ class TAPCapabilityMaker(CapabilityMaker):
 								TR.form[funcName]]
 							for funcName in ("BOX", "POINT", "CIRCLE", "POLYGON",
 									"REGION", "CENTROID", "COORD1", "COORD2",
-									"DISTANCE", "CONTAINS", "INTERSECTS", "AREA", "MOC")]],
+									"DISTANCE", "CONTAINS", "INTERSECTS", "AREA")]],
 
 						TR.languageFeatures(
 								type="ivo://ivoa.net/std/TAPRegExt#features-adql-string")[
@@ -530,7 +530,14 @@ class TAPCapabilityMaker(CapabilityMaker):
 									" 10% of the rows; these are `somewhat random' in"
 									" that the system will use random blocks.  This"
 									" should be good enough when just testing queries"
-									" (and much better than using TOP n)."]]],
+									" (and much better than using TOP n)."]],
+							TR.feature[
+								TR.form["MOC"],
+								TR.description["A geometry function creating MOCs."
+									"  It either takes a string argument with an ASCII"
+									" MOC ('4/13 17-18 8/3002'), or an order and another"
+									" geometry."]],
+							],
 
 						TR.languageFeatures(
 								type="ivo://ivoa.net/std/TAPRegExt#features-adql-sets")[
