@@ -66,6 +66,15 @@ def makeBaseRecord(res, keepTimestamp=False):
 	# manage its authority
 	ivoid = base.getMetaText(res, "identifier")
 	auth = urllib.parse.urlparse(ivoid).netloc
+
+	if auth=="x-unregistred":
+		raise base.ReportableError("Resource from %s uses the authority"
+			" x-unregistered; this is not permitted."%res.rd.sourceId,
+			hint="This in all likelihood means that you are not setting"
+			" the [ivoa]authority config item in your gavo.rc.  Read up"
+			" on 'Choosing your authority' in the tutorial to see how"
+			" to fix this.")
+
 	if not auth in getManagedAuthorities():
 		base.ui.notifyWarning("Skipping publication of resource"
 			" with identifier %s because we don't manage its authority"%
