@@ -105,7 +105,7 @@ function makeQueryItem(element) {
 // returns an url-encoded query tag item out of a form element
 	var val=null;
 
-	switch (element.nodeName) {
+	switch (element.nodeName.toUpperCase()) {
 		case "INPUT":
 		case "TEXTAREA":
 			if (element.type=="radio" || element.type=="checkbox") {
@@ -131,6 +131,17 @@ function makeQueryItem(element) {
 	}
 }
 
+
+function completeURL(uriOrPath) {
+	// guesses whether uriOrPath has a host part and adds the
+	// current one if necessary.
+	// This for now does not support relative paths.
+	if (uriOrPath[0]=="/") {
+		return window.location.protocol+"//"+window.location.host+uriOrPath;
+	}
+	return uriOrPath;
+}
+
 function getFormQuery(form, ignoreNames) {
 	// returns a link to the result sending the HTML form form would
 	// yield.
@@ -144,7 +155,7 @@ function getFormQuery(form, ignoreNames) {
 			fragments.push(fragment);
 		} 
 	}
-	return form.getAttribute("action")+"?"+fragments.join("&");
+	return completeURL(form.getAttribute("action")+"?"+fragments.join("&"));
 }
 
 
@@ -172,6 +183,41 @@ function followEmbeddedLink(parent) {
 	}
 }
 
+///////////// letting people bookmark anchors
+
+function _add_anchor(ev) {
+	var anchor = document.createElement("a");
+	anchor.setAttribute("class", "linkAnchor");
+	anchor.innerHTML = "¶";
+	anchor.href = "#"+this.id;
+	this.appendChild(anchor);
+}
+
+
+function _remove_anchor(ev) {
+	var parent = this;
+	parent.querySelectorAll(".linkAnchor").forEach(
+		function(c) {
+			parent.removeChild(c);
+		});
+}
+
+
+function _add_anchor_shower(el) {
+	if (el.id) {
+		el.addEventListener("mouseenter", _add_anchor);
+		el.addEventListener("mouseleave", _remove_anchor);
+	}
+}
+
+function add_anchors_to_heads() {
+// adds linkable anchors to all h? elements with ids.
+// this is supposed to be run from a document.ready callback.
+	document.querySelectorAll("h1,h2,h3,h4,h5"
+		).forEach(_add_anchor_shower);
+}
+
+
 ///////////// Functions dealing with the output format widget
 // This incredibly verbose crap hides and shows widgets selecting aspects
 // of the output format.  Basically, you have widgets in output_bussedElements
@@ -320,6 +366,7 @@ $(document).ready(
 	function() {
 		output_init();
 		init_preview_observer();
+		add_anchors_to_heads();
 	});
 
 
@@ -467,6 +514,7 @@ function insertPreview(node, width) {
 		).attr("alt", "[preview image]");
 
 	img.bind("load", function() {
+		jqNode.prepend($("<br/>"));
 		jqNode.prepend(img[0], node.firstChild);
 		jqNode.removeClass("busy");
 	});
