@@ -1603,20 +1603,6 @@ RegionEditor_mVc.prototype = {
 				that.controller.invokeHandler(true);
 			});
 			
-			divButtons.append("<br><span style='font-size: small;'>&nbsp;Go To: </span>");
-			this.posField = $("<input type='text' id='position' size=24 />");
-			divButtons.append(this.posField);
-			this.posField.css('margin-top','10px');
-			this.posField.css('margin-left','5px');
-			this.posField.keyup(function(e){
-				if(e.keyCode == 13){
-					var pos = $(this).val().replace(/:/g , " ");
-					that.posField.val(pos);
-					that.aladin.gotoObject(pos);
-					$(this).val(pos);
-					that.aladin.gotoObject(pos);
-				}
-			});
 			if( this.editionFrame ){
 				this.setEditionFrame(this.editionFrame);
 				this.setEditMode();
@@ -1711,7 +1697,6 @@ RegionEditor_mVc.prototype = {
 							}
 						} else {
 							var pos = s[1].replace(/:/g , " ");
-							this.posField.val(pos);
 							this.aladin.setZoom(0.55);
 							this.aladin.gotoObject(pos);
 						}
