@@ -394,7 +394,7 @@ class DBTable(DBMethodsMixin, table.BaseTable, MetaTableMixin):
 		cursor.close()
 
 	def __len__(self):
-		return list(self.query("select count(*) from %s"%
+		return list(self.connection.query("select count(*) from %s"%
 			self.tableDef.getQName()))[0][0]
 
 	def exists(self):
@@ -600,8 +600,16 @@ class DBTable(DBMethodsMixin, table.BaseTable, MetaTableMixin):
 	def drop(self):
 		"""drops the table.
 		"""
+		self.runScripts("beforeDrop")
 		if self.exists():
-			self.runScripts("beforeDrop")
+			# if there are any dependent views (known), drop them in a controlled
+			# fashion becore CASCADE hits
+			for viewId in self.tableDef.derivedViews:
+				View(
+					base.resolveCrossId(viewId),
+					connection=self.connection,
+					create=False).drop()
+
 			self.dropTable(self.tableDef.getQName(), cascade=True)
 			if not self.nometa:
 				self.cleanFromMeta()
@@ -716,7 +724,7 @@ class DBTable(DBMethodsMixin, table.BaseTable, MetaTableMixin):
 			samplePercent=samplePercent)
 		return table.InMemoryTable(resultTableDef,
 			rows=[resultTableDef.makeRowFromTuple(tupRow)
-				for tupRow in self.query(query, pars)])
+				for tupRow in self.connection.query(query, pars)])
 
 	def runScripts(self, phase, **kwargs):
 		"""runs scripts from both the tableDef and the make.
