@@ -538,8 +538,15 @@ def getStandardPubDID(path):
 	if path[0]!="/":
 		path = os.path.join(base.getConfig("inputsDir"), path)
 
+	auth = base.getConfig("ivoa", "authority")
+	if auth=="x-unregistred":
+		raise base.ReportableError("You must configure your IVOA authority"
+			" before creating standard PubDIDs.",
+			hint="Read up on 'Choosing your authority' in the tutorial to see how"
+			" to fix this.")
+
 	return "ivo://%s/~?%s"%(
-		base.getConfig("ivoa", "authority"), 
+		auth,
 		getInputsRelativePath(path, liberalChars=True))
 
 
