@@ -220,10 +220,11 @@ class MixinDef(activetags.ReplayBase):
 					self.macroExpansions)
 
 			if self.processLate is not None:
-				def procLate(rootStruct, parseContext):
+				def procLate(rootStruct, parseContext, 
+						destination=destination, exp=self.macroExpansions.copy()):
 					self.processLate.compile(destination)(
 						destination, rootStruct, 
-						parseContext, self.macroExpansions.copy())
+						parseContext, exp)
 				ctx.addExitFunc(procLate)
 
 		if self.lateEvents:
