@@ -621,7 +621,7 @@ class CachedException(object):
 	This will remain in the cache until the underlying RD is changed.
 	"""
 	def __init__(self, exception, sourcePath):
-		self.exception = exception
+		self.exception = exception.with_traceback(None)
 		self.sourcePath = sourcePath
 		# this can race a bit in that we won't catch saves done between
 		# we started parsing and we came up with the exception, but
@@ -645,7 +645,7 @@ class CachedException(object):
 	
 	def raiseAgain(self):
 		# XXX TODO: do we want to fix the traceback here?
-		raise self.exception
+		raise self.exception.with_traceback(None)
 
 
 def _loadRDIntoCache(canonicalRDId, cacheDict):
