@@ -211,7 +211,11 @@ class CustomRF(CustomPageFunction):
 
 	Also, the active renderer is visible as self; the one thing you
 	might want to see from there is self.queryMeta, which contains,
-	for instance, the input parameters.
+	for instance, the input parameters (but be careful: the inputTable
+	will be None when input errors are rendered, so better to code
+	using it like this::
+
+		if self.queryMeta["inputTable"] and self.queryMeta["inputTable"]...:
 
 	You can return anything that can be in a stan DOM.  Usually, this will be
 	a string.  To return HTML, use the stan DOM available under the T namespace.
