@@ -85,7 +85,7 @@ def delfromgroup(querier, args):
 
 @exposedFunction(help="list users known to the DC")
 def listusers(querier, args):
-	data = list(querier.query("SELECT username, groupname, remarks"
+	data = list(querier.connection.query("SELECT username, groupname, remarks"
 		" FROM dc.users NATURAL JOIN dc.groups ORDER BY username"))
 	curUser = None
 	for user, group, remark in data:
@@ -274,7 +274,8 @@ def makedelrec(querier, args):
 	" RDs mentioned in TAP_SCHEMA.")
 def updateTAPSchema(querier, args):
 	from gavo.protocols import tap
-	for rdId, in querier.query("select sourcerd from TAP_SCHEMA.tables"):
+	for rdId, in querier.connection.query(
+			"select sourcerd from TAP_SCHEMA.tables"):
 		try:
 			rd = base.caches.getRD(rdId)
 			tap.publishToTAP(rd, querier.connection)
