@@ -11,6 +11,7 @@ Various helpers that didn't fit into any other xTricks.
 import base64
 import collections
 import contextlib
+import functools
 import io
 import os
 import re
@@ -214,6 +215,7 @@ class Undefined(object, metaclass=_UndefinedType):
 		raise TypeError("Undefined cannot be instantiated.")
 
 
+@functools.total_ordering
 class QuotedName(object):
 	"""A string-like thing basically representing SQL delimited identifiers.
 
@@ -235,6 +237,8 @@ class QuotedName(object):
 	(False, True, True)
 	>>> print(n1, n2)
 	"foo" "foo""l"
+	>>> "Foo"<n1, n1>"bar"
+	(False, True)
 	"""
 	def __init__(self, name):
 		self.name = name
@@ -250,8 +254,13 @@ class QuotedName(object):
 		else:
 			return False
 
-	def __ne__(self, other):
-		return not self==other
+	def __lt__(self, other):
+		if isinstance(other, QuotedName):
+			return self.name<other.name
+		elif isinstance(other, str):
+			return self.name<other.lower()
+		else:
+			return False
 
 	def __str__(self):
 		return '"%s"'%(self.name.replace('"', '""'))
