@@ -173,7 +173,7 @@ def getXtypeEncoderCode(field):
 			"if isinstance(val, pgsphere.PgSAdapter):",
 			"  val = val.asSTCS('UNKNOWNFrame')"])
 
-	elif field.xtype in ["point", "circle", "polygon", "moc", "x:box"]:
+	elif field.xtype in ["point", "circle", "polygon", "moc", "x-box"]:
 		return loopify([
 			"if isinstance(val, pgsphere.PgSAdapter):",
 			"  val = val.asDALI()"])
@@ -234,7 +234,7 @@ def getXtypeDecoderCode(field):
 		src.extend([
 			"  val = pgsphere.SMoc.fromDALI(val)"])
 
-	elif field.xtype=="x:box":
+	elif field.xtype=="x-box":
 		src.extend([
 			"  val = pgsphere.SBox.fromDALI(val)"])
 
