@@ -8,12 +8,13 @@ Common code for the nevow based interface.
 #c COPYING file in the source distribution.
 
 
+import cgi
 import io
 import json
 import re
 import urllib.request, urllib.parse, urllib.error
+from email.message import Message
 
-import twisted
 from twisted.python import failure
 from twisted.web import resource
 from twisted.web import server
@@ -26,6 +27,7 @@ except ImportError:
 	_PY3, _PY37PLUS = True, False
 from twisted.web.template import tags as T
 from twisted.web import http
+from twisted.web.http import parse_qs
 
 from gavo import base
 from gavo import svcs
@@ -235,6 +237,104 @@ class CommonRenderers(object):
 		return tag[content]
 
 
+class TypedData(resource.Resource):
+	"""A simple resource just producing bytes passed in during construction,
+	declared as a special content type.
+	"""
+	def __init__(self, data, mime, modificationStamp=None):
+		resource.Resource.__init__(self)
+		self.data, self.mime = data, mime
+		self.modificationStamp = modificationStamp
+	
+	def render(self, request):
+		request.setHeader("content-type", self.mime)
+
+		if self.modificationStamp is not None:
+			if request.setLastModified(self.modificationStamp)==http.CACHED:
+				return b""
+
+		request.write(self.data)
+		request.finish()
+		return server.NOT_DONE_YET
+
+
+class JSONQuery(resource.Resource):
+	"""A resource returning JSON for a database query.
+
+	Have the query in a query attribute to the class.  Use %(whatever)s
+	to put in the first match of that in request.strargs.
+
+	TODO: we should do some more sensible error handling.
+	"""
+	def doQuery(self, queryArgs):
+		"""returns a list of dictionaries for the query result.  The default
+		just executes self.query.
+		"""
+		with base.getTableConn() as conn:
+			return list(conn.queryToDicts(
+				self.query, queryArgs))
+
+
+	def render(self, request):
+		queryArgs = dict((key, value[0])
+			for key, value in request.strargs.items())
+
+		res = self.doQuery(queryArgs)
+
+		request.setHeader("content-type", "text/json")
+		return json.dumps(res).encode("utf-8")
+
+
+####################### Start twisted request overhaul
+#
+# Python 3 twisted has had quite a few severe shortcomings which I
+# hacked around for a while.  In the end, people said I might as
+# well just override requestReceived in a way convenient for me.
+#
+# This is what happens here, together with some support code.
+#
+# twisted.web uses cgi.parse_multipart that, in python3, internally uses
+# cgi.FieldStorage.  I really can't live without FieldStorage in DaCHS,
+# what with all the uploads that are being hurled around in various ways.
+# But I don't want to construct the FieldStorage a second time because we
+# may have fairly substantial amounts of upload and because it sucks.
+# However, the parse_multipart thing is in the midst of a large chunk of
+# code in twisted.web.server, and the request.args interface is hard
+# to change anyway.  So, I instead hack cgi.parse_multipart to be what
+# it is in python3.7; it will now return its internal FieldStorage in
+# a magic key in the attribute that I pick out in requestReceived.
+# While I'm at it, I also remove file uploads from request.args, which makes
+# my life easier in some other ways.
+
+def parse_multipart(fp, pdict, encoding="utf-8", errors="replace"):
+	"""Parse multipart input from an input file fp.
+
+	pdict is a dictionary containing other parameters of content-type header,
+	encoding and errors is the request encoding and error handler, passed to
+  FieldStorage
+
+	This is the basically python 3.7 implementation of this, except I'm
+	returning the internal FieldStorage in the dictionary (key None).
+	"""
+# RFC 2026, Section 5.1 : The "multipart" boundary delimiters are always
+# represented as 7bit US-ASCII.
+	boundary = pdict['boundary'].decode('ascii')
+	ctype = "multipart/form-data; boundary={}".format(boundary)
+	headers = Message()
+	headers.set_type(ctype)
+	headers['Content-Length'] = pdict['CONTENT-LENGTH']
+	fs = cgi.FieldStorage(fp, 
+		headers=headers, 
+		encoding=encoding,
+	 	errors=errors,
+		environ={'REQUEST_METHOD': 'POST'})
+	res = {k: fs.getlist(k)[:] for k in fs}
+	res[_FSHACK_MAGIC] = fs
+	return res
+
+cgi.parse_multipart = parse_multipart
+
+
 class BinaryItem:
 	"""A sentinel marking request.args items that couldn't be utf-8 decoded
 
@@ -293,6 +393,14 @@ class _UploadLimiter(object):
 		else:
 			self.original.write(bytes)
 
+	def finish(self):
+		"""break cycles and return our original.
+
+		This is mainly a curtesy to the garbage collector.
+		"""
+		del self.request
+		return self.original
+
 
 class Request(server.Request):
 	"""a custom request class used in DaCHS' application server.
@@ -542,62 +650,7 @@ class Request(server.Request):
 			self.fields = self.args.pop(_FSHACK_MAGIC.encode("ascii"), None)
 		server.Request.process(self)
 
-
-####### FieldStorage hack start
-# twisted.web uses cgi.parse_multipart that, in python3, internally uses
-# cgi.FieldStorage.  I really can't live without FieldStorage in DaCHS,
-# what with all the uploads that are being hurled around in various ways.
-# But I don't want to construct the FieldStorage a second time because we
-# may have fairly substantial amounts of upload and because it sucks.
-# However, the parse_multipart thing is in the midst of a large chunk of
-# code in twisted.web.server, and the request.args interface is hard
-# to change anyway.  So, I instead hack cgi.parse_multipart to be what
-# it is in python3.7; it will now return its internal FieldStorage in
-# a magic key in the attribute that I pick out in requestReceived.
-# While I'm at it, I also remove file uploads from request.args, which makes
-# my life easier in some other ways.
-
-import cgi
-from email.message import Message
-
-def parse_multipart(fp, pdict, encoding="utf-8", errors="replace"):
-	"""Parse multipart input from an input file fp.
-
-	pdict is a dictionary containing other parameters of content-type header,
-	encoding and errors is the request encoding and error handler, passed to
-  FieldStorage
-
-	This is the basically python 3.7 implementation of this, except I'm
-	returning the internal FieldStorage in the dictionary (key None).
-	"""
-# RFC 2026, Section 5.1 : The "multipart" boundary delimiters are always
-# represented as 7bit US-ASCII.
-	boundary = pdict['boundary'].decode('ascii')
-	ctype = "multipart/form-data; boundary={}".format(boundary)
-	headers = Message()
-	headers.set_type(ctype)
-	headers['Content-Length'] = pdict['CONTENT-LENGTH']
-	fs = cgi.FieldStorage(fp, 
-		headers=headers, 
-		encoding=encoding,
-	 	errors=errors,
-		environ={'REQUEST_METHOD': 'POST'})
-	res = {k: fs.getlist(k)[:] for k in fs}
-	res[_FSHACK_MAGIC] = fs
-	return res
-
-cgi.parse_multipart = parse_multipart
-
-####### FieldStorage hack end
-
-
-if (18,7)<=(twisted.version.major, twisted.version.minor)<=(20, 8):
-	# a certain range of twisted releases had a bug that would break chunked
-	# uploads.  We monkeypatch Request to fix this.  And we're also
-	# fixing the deficiency that Request no longer exposes file uploads...
-	from twisted.web.http import parse_qs
-	import cgi
-
+	@staticmethod
 	def _parseHeader(line):
 		# cgi.parse_header requires a str
 		key, pdict = cgi.parse_header(line.decode('charmap'))
@@ -608,18 +661,21 @@ if (18,7)<=(twisted.version.major, twisted.version.minor)<=(20, 8):
 		pdict = {x:y.encode('charmap') for x, y in pdict.items()}
 		return (key, pdict)
 
-	def fixed_requestReceived(self, command, path, version):
-		"""code from 19.7 http.Request.requestReceived.
-
-		Changes vs. twisted:
-		
-		* removed a strategic "and clength"
-		* changed _parseHeader to cgi.parse_header
-		* I'm pulling the _FSHACK_MAGIC from cgiArgs before twisted code
-		  butchers it.
-		* I'm reading in the whole request body into a BytesIO because
-      python cgi really can't live without clength.
-		"""
+	def requestReceived(self, command, path, version):
+		# overridden because several upstream versions broke chunked
+		# uploads, and then to restore file uploads, which it broke
+		# a bit later.
+		# This is essentially requestReceived as of twisted 19.7 or so,
+		# with quite a few version switches removed because DaCHS only
+		# runs with python 3.7 or later anyway.
+		#
+		# changes vs. twisted:
+		#
+		# * removed a strategic "and clength"
+		# * I'm pulling the _FSHACK_MAGIC from cgiArgs before twisted code
+		#   butchers it.
+		# * I'm reading in the whole request body into a BytesIO because
+    #   python cgi really can't live without clength.
 		self.content.seek(0,0)
 		self.args = {}
 
@@ -645,50 +701,37 @@ if (18,7)<=(twisted.version.major, twisted.version.minor)<=(20, 8):
 
 		if self.method == b"POST" and ctype:
 			mfd = b'multipart/form-data'
-			key, pdict = _parseHeader(ctype)
+			key, pdict = self._parseHeader(ctype)
 			pdict["CONTENT-LENGTH"] = clength
 			if key == b'application/x-www-form-urlencoded':
 				args.update(parse_qs(self.content.read(), 1))
 			elif key == mfd:
 				try:
-					if _PY37PLUS:
-						# HACK ALERT: if clength is none, in this situation we probably have
-						# a chunked upload.  cgi.FieldStorage can't deal with that in
-						# python 3.7.  We pull in the whole stuff synchronously to cope
-						# and hope for the best in terms of blocking behaviour...
-						# TODO: We really should go back to just passing content.
-						if clength is None:
-							uploaded = io.BytesIO(self.content.read())
-							self.content = uploaded
-							pdict["CONTENT-LENGTH"] = len(uploaded.getvalue())
+					# HACK ALERT: if clength is none, in this situation we probably have
+					# a chunked upload.  cgi.FieldStorage can't deal with that in
+					# python 3.7.  We pull in the whole stuff synchronously to cope
+					# and hope for the best in terms of blocking behaviour...
+					# TODO: We really should go back to just passing content.
+					if clength is None:
+						uploaded = io.BytesIO(self.content.read())
+						self.content = uploaded
+						pdict["CONTENT-LENGTH"] = len(uploaded.getvalue())
 
-						cgiArgs = cgi.parse_multipart(
-							self.content, pdict, encoding='utf8',
-							errors="surrogateescape")
-					else:
-						cgiArgs = cgi.parse_multipart(self.content, pdict)
+					cgiArgs = cgi.parse_multipart(
+						self.content, pdict, encoding='utf8',
+						errors="surrogateescape")
 
-					if not _PY37PLUS and _PY3:
-						# The parse_multipart function on Python 3
-						# decodes the header bytes as iso-8859-1 and
-						# returns a str key -- we want bytes so encode
-						# it back
-						self.args.update({x.encode('iso-8859-1'): y
-										  for x, y in cgiArgs.items()})
-					elif _PY37PLUS:
-						# The parse_multipart function on Python 3.7+
-						# decodes the header bytes as iso-8859-1 and
-						# decodes the body bytes as utf8 with
-						# surrogateescape -- we want bytes
-						self.fields = cgiArgs.pop(_FSHACK_MAGIC, {})
-						self.args.update({
-							x.encode('iso-8859-1'): \
-							[z.encode('utf8', "surrogateescape")
-							 if isinstance(z, str) else z for z in y]
-							for x, y in cgiArgs.items()})
+					# The parse_multipart function on Python 3.7+
+					# decodes the header bytes as iso-8859-1 and
+					# decodes the body bytes as utf8 with
+					# surrogateescape -- we want bytes
+					self.fields = cgiArgs.pop(_FSHACK_MAGIC, {})
+					self.args.update({
+						x.encode('iso-8859-1'): \
+						[z.encode('utf8', "surrogateescape")
+						 if isinstance(z, str) else z for z in y]
+						for x, y in cgiArgs.items()})
 
-					else:
-						self.args.update(cgiArgs)
 				except Exception as e:
 					# It was a bad request, or we got a signal.
 					self.channel._respondToBadRequestAndDisconnect()
@@ -697,19 +740,19 @@ if (18,7)<=(twisted.version.major, twisted.version.minor)<=(20, 8):
 					else:
 						# If it's not a userspace error from CGI, reraise
 						raise
+				self.content.seek(0,0)
 
-			self.content.seek(0, 0)
+		# take the upload limiter out of content; it's done its work
+		if hasattr(self.content, "finish"):
+			self.content = self.content.finish()
 
 		self.process()
 
-	server.Request.requestReceived = fixed_requestReceived
-	del fixed_requestReceived
-
 
 ######################## cgi.make_file workaround
 # The cgi module creates temporary disk files under the assumption
 # its process is short-lived.  Well, DaCHS processes aren't and so
-# we override make_file; again, we have plenty for RAM and not terriby
+# we override make_file; again, we have plenty of RAM and not terribly
 # many concurrent users, so we keep things off the disk and avoid
 # the use of FDs (that aren't returned if they are used).
 
@@ -719,53 +762,3 @@ def _monkey_make_file(self):
 	else:
 		return io.StringIO()
 cgi.FieldStorage.make_file = _monkey_make_file
-
-
-class TypedData(resource.Resource):
-	"""A simple resource just producing bytes passed in during construction,
-	declared as a special content type.
-	"""
-	def __init__(self, data, mime, modificationStamp=None):
-		resource.Resource.__init__(self)
-		self.data, self.mime = data, mime
-		self.modificationStamp = modificationStamp
-	
-	def render(self, request):
-		request.setHeader("content-type", self.mime)
-
-		if self.modificationStamp is not None:
-			if request.setLastModified(self.modificationStamp)==http.CACHED:
-				return b""
-
-		request.write(self.data)
-		request.finish()
-		return server.NOT_DONE_YET
-
-
-class JSONQuery(resource.Resource):
-	"""A resource returning JSON for a database query.
-
-	Have the query in a query attribute to the class.  Use %(whatever)s
-	to put in the first match of that in request.strargs.
-
-	TODO: we should do some more sensible error handling.
-	"""
-	def doQuery(self, queryArgs):
-		"""returns a list of dictionaries for the query result.  The default
-		just executes self.query.
-		"""
-		with base.getTableConn() as conn:
-			return list(conn.queryToDicts(
-				self.query, queryArgs))
-
-
-	def render(self, request):
-		queryArgs = dict((key, value[0])
-			for key, value in request.strargs.items())
-
-		res = self.doQuery(queryArgs)
-
-		request.setHeader("content-type", "text/json")
-		return json.dumps(res).encode("utf-8")
-
-
