@@ -134,6 +134,15 @@ class Examples(grend.CustomTemplateMixin, grend.ServiceBasedPage):
 	checkedRenderer = False
 	customTemplate = svcs.loadSystemTemplate("examples.html")
 
+	def render(self, request):
+		# overridden to return a 404 when there are no examples,
+		# which is what TOPCAT wants.
+		self.serviceExamples = list(
+			self.service.iterMeta("_example"))
+		if not self.serviceExamples:
+			request.setResponseCode(404)
+		return grend.ServiceBasedPage.render(self, request)
+
 	@classmethod
 	def isCacheable(self, segments, request):
 		return True
@@ -143,10 +152,16 @@ class Examples(grend.CustomTemplateMixin, grend.ServiceBasedPage):
 		return tag["Examples for %s"%base.getMetaText(
 			self.service, "title")]
 
+	@template.renderer
+	def noexamples(self, request, tag):
+		if not self.serviceExamples:
+			return tag
+		return ""
+
 	def data_examples(self, request, tag):
 		"""returns _Example instances from the service metadata.
 		"""
-		for ex in self.service.iterMeta("_example"):
+		for ex in self.serviceExamples:
 			yield _Example(ex)
 
 	def data_rendered(self, request, tag):
