@@ -174,13 +174,11 @@ class StaticFile(static.File):
 
 		ext = os.path.splitext(self.path)[1]
 		if ext in self.processors:
-			cache = base.caches.getPageCache(self.cacheRD.sourceId)
-			cachedRes = cache.get(self.path)
+			cachedRes = caching.getFromRDCache(
+				request, self.cacheRD, self.path.split("/"))
 			if cachedRes is not None and cachedRes.creationStamp>modStamp:
 				return cachedRes.render(request)
 
-			caching.instrumentRequestForCaching(request,
-				caching.enterIntoCacheAs(self.path, cache))
 			processed = self.processors[ext](request, self.path)
 			if hasattr(processed, "render"):
 				return processed.render(request)
@@ -276,7 +274,8 @@ class GavoJquery(resource.Resource):
 			"""),
 		"jquery-ui/ui/widgets/draggable.js",
 		"jquery-ui/ui/widgets/resizable.js",
-
+		"jquery-ui/ui/safe-active-element.js",
+		"jquery-ui/ui/safe-blur.js",
 		io.StringIO("}));"),
 		]
 
@@ -472,6 +471,9 @@ class Teapot(resource.Resource):
 		request.setResponseCode(418)
 		return b"I'm a tea pot.  Of course.\r\n"
 
+	def getChild(self, name, request):
+		return self
+
 
 ############### resources for the javascript-enabled root page
 # These once had a module of their own, which I didn't like.
@@ -583,3 +585,21 @@ ROOT_PAGE_HELPERS.putChild(b"bySubject", BySubject())
 ROOT_PAGE_HELPERS.putChild(b"byAuthor", ByAuthor())
 ROOT_PAGE_HELPERS.putChild(b"byFulltext", ByFulltext())
 ROOT_PAGE_HELPERS.putChild(b"serviceInfo", ServiceInfo())
+
+
+if __name__=="__main__":
+	# you can call this module to update jquery-gavo.js and jquery.flot.js
+	# as is distributed in the tarball to what Debian gives upstream.
+	# See develNotes.rstx in our docs.
+	for path, data in DEBIAN_FALLBACKS.items():
+		if not path.startswith("js/"):
+			continue
+		if isinstance(data, str):
+			with open(data, "rb") as f:
+				payload = f.read()
+		else:
+			base.setConfig("web", "jsSource", "True")
+			payload = data._getContent().encode("utf-8")
+
+		with open(path[3:], "wb") as f:
+			f.write(payload)
